ovh
    * ``auth_entrypoint`` Specify the ovh entrypoint

    * ``auth_application_key`` Specify the application key

    * ``auth_application_secret`` Specify the application secret

    * ``auth_consumer_key`` Specify the consumer key


.. note::
   
   OVH Provider requires a token with full rights on /domain/*.
   It can be generated for your OVH account on the following URL:
   https://api.ovh.com/createToken/index.cgi?GET=/domain/*&PUT=/domain/*&POST=/domain/*&DELETE=/domain/*

